summary refs log tree commit diff
path: root/guix
diff options
context:
space:
mode:
authorNicolas Goaziou <mail@nicolasgoaziou.fr>2023-06-26 12:00:51 +0200
committerNicolas Goaziou <mail@nicolasgoaziou.fr>2023-07-18 18:16:08 +0200
commit19fd1004138b60c4479d7516aa0cee261c0b6b57 (patch)
treea9ffdb460141860cdacd1f37562f88a6c86baf6e /guix
parent0561616a3208aa17fe5b1f9c425c44fe00218b08 (diff)
downloadguix-19fd1004138b60c4479d7516aa0cee261c0b6b57.tar.gz
gnu: Externalize libkpathsea in texlive and texlive-bin.
* gnu/packages/tex.scm (texlive-libkpathsea): New variable.
(texlive-bin): Inherit from above.
[arguments]<#:configure-flags>: Use "--disable-kpathsea",
"--with-system-kpathsea", "--with-kpathsea-includes" and
"--with-kpathsea-lib".
<#:phases>: Remove phases now handled by the package above.
[native-inputs]: Add GROFF-MINIMAL.
[propagated-inputs]: Add TEXLIVE-LIBKPATHSEA.
(texlive-bin-full): New variable.
(texlive-texmf)[build-system]: Use COPY-BUILD-SYSTEM.
[arguments]: Set #:INSTALL-PLAN accordingly.  Replace TEXLIVE-BIN with
TEXLIVE-BIN-FULL.
* guix/profiles.scm (texlive-font-maps): Fetch executables from
TEXLIVE-LIBKPATHSEA instead of TEXLIVE-BIN.
Diffstat (limited to 'guix')
-rw-r--r--guix/profiles.scm10
1 files changed, 5 insertions, 5 deletions
diff --git a/guix/profiles.scm b/guix/profiles.scm
index 35208dd0c9..75ce2b4d08 100644
--- a/guix/profiles.scm
+++ b/guix/profiles.scm
@@ -1791,8 +1791,8 @@ MANIFEST."
     (append-map entry->texlive-input (manifest-entries manifest)))
   (define texlive-scripts
     (module-ref (resolve-interface '(gnu packages tex)) 'texlive-scripts))
-  (define texlive-bin
-    (module-ref (resolve-interface '(gnu packages tex)) 'texlive-bin))
+  (define texlive-libkpathsea
+    (module-ref (resolve-interface '(gnu packages tex)) 'texlive-libkpathsea))
   (define coreutils
     (module-ref (resolve-interface '(gnu packages base)) 'coreutils))
   (define grep
@@ -1818,8 +1818,8 @@ MANIFEST."
                        #:create-all-directories? #t
                        #:log-port (%make-void-port "w"))
 
           ;; XXX: This is annoying, but it's necessary because texlive-bin
           ;; does not provide wrapped executables.
           (setenv "PATH"
                   (string-append #$(file-append coreutils "/bin")
                                  ":"
@@ -1827,7 +1827,7 @@ MANIFEST."
                                  ":"
                                  #$(file-append sed "/bin")
                                  ":"
-                                 #$(file-append texlive-bin "/bin")))
+                                 #$(file-append texlive-libkpathsea "/bin")))
           (setenv "PERL5LIB" #$(file-append texlive-scripts "/share/tlpkg"))
           (setenv "GUIX_TEXMF" "/tmp/texlive/share/texmf-dist")
@@ -1818,8 +1818,8 @@ MANIFEST."
                        #:log-port (%make-void-port "w"))
 
-          ;; XXX: This is annoying, but it's necessary because texlive-bin
-          ;; does not provide wrapped executables.
+          ;; XXX: This is annoying, but it's necessary because
+          ;; texlive-libkpathsea does not provide wrapped executables.
           (setenv "PATH"
                   (string-append #$(file-append coreutils "/bin")